==> Paws-0.35.tar.gz: Paws-0.35/lib/Paws/Organizations/EnableAllFeatures.pm <==

package Paws::Organizations::EnableAllFeatures;
  use Moose;

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'EnableAllFeatures');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Organizations::EnableAllFeaturesResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Organizations::EnableAllFeatures - Arguments for method EnableAllFeatures on Paws::Organizations

=head1 DESCRIPTION

This class represents the parameters used for calling the method EnableAllFeatures on the 
AWS Organizations service. Use the attributes of this class
as arguments to method EnableAllFeatures.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to EnableAllFeatures.

As an example:

  $service_obj->EnableAllFeatures(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES



=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method EnableAllFeatures in L<Paws::Organizations>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.43.tar.gz: Paws-0.43/lib/Paws/Organizations/EnableAllFeatures.pm <==

package Paws::Organizations::EnableAllFeatures;
  use Moose;

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'EnableAllFeatures');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Organizations::EnableAllFeaturesResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Organizations::EnableAllFeatures - Arguments for method EnableAllFeatures on L<Paws::Organizations>

=head1 DESCRIPTION

This class represents the parameters used for calling the method EnableAllFeatures on the
L<AWS Organizations|Paws::Organizations> service. Use the attributes of this class
as arguments to method EnableAllFeatures.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to EnableAllFeatures.

=head1 SYNOPSIS

    my $organizations = Paws->service('Organizations');
    my $EnableAllFeaturesResponse = $organizations->EnableAllFeatures();

    # Results:
    my $Handshake = $EnableAllFeaturesResponse->Handshake;

    # Returns a L<Paws::Organizations::EnableAllFeaturesResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/organizations/EnableAllFeatures>

=head1 ATTRIBUTES



=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method EnableAllFeatures in L<Paws::Organizations>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
